@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::InitTarget;
 
-our $VERSION = 0.009; # VERSION
+our $VERSION = "0.010"; # VERSION
 
 our $results = [
   [
@@ -8,60 +8,60 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.0011,
+        errors => 0.0024,
         participant => "with LGO:Composite (Screen+File & pattern layouts)",
-        rate => 2.6,
+        rate => 2.3,
         samples => 7,
-        time => 380,
+        time => 440,
         vs_slowest => 1,
       },
       {
-        errors => 0.00037,
+        errors => 0.0063,
         participant => "default",
-        rate => 2.66,
+        rate => 2,
         samples => 7,
-        time => 377,
-        vs_slowest => 1.02,
+        time => 400,
+        vs_slowest => 1,
       },
       {
-        errors => 0.00054,
+        errors => 0.0023,
         participant => "with LGO:Composite (Screen+File)",
-        rate => 2.8,
-        samples => 8,
-        time => 350,
+        rate => 2.5,
+        samples => 7,
+        time => 400,
         vs_slowest => 1.1,
       },
       {
-        errors => 0.00042,
+        errors => 0.0015,
         participant => "with LGO:Composite (Screen)",
-        rate => 3.7,
+        rate => 3.2,
         samples => 7,
-        time => 270,
+        time => 310,
         vs_slowest => 1.4,
       },
       {
-        errors => 2.6e-05,
-        participant => "with LGO:File",
-        rate => 8.23,
-        samples => 7,
-        time => 122,
-        vs_slowest => 3.16,
-      },
-      {
-        errors => 0.00029,
-        participant => "with LGO:Composite (0 outputs)",
-        rate => 8.3,
-        samples => 7,
-        time => 120,
-        vs_slowest => 3.2,
-      },
-      {
-        errors => 7.1e-05,
+        errors => 0.0018,
         participant => "with LGO:Screen",
-        rate => 8.3,
+        rate => 7,
+        samples => 7,
+        time => 100,
+        vs_slowest => 3,
+      },
+      {
+        errors => 0.00081,
+        participant => "with LGO:Composite (0 outputs)",
+        rate => 6.9,
         samples => 8,
-        time => 120,
-        vs_slowest => 3.19,
+        time => 140,
+        vs_slowest => 3,
+      },
+      {
+        errors => 0.00021,
+        participant => "with LGO:File",
+        rate => 7,
+        samples => 7,
+        time => 140,
+        vs_slowest => 3.1,
       },
     ],
     {
@@ -184,7 +184,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2200.078,
+                                              speed                        => 2178.914,
                                               stepping                     => 4,
                                             },
                                             {
@@ -299,7 +299,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2199.968,
+                                              speed                        => 2197.015,
                                               stepping                     => 4,
                                             },
                                             {
@@ -414,7 +414,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2199.968,
+                                              speed                        => 2200.132,
                                               stepping                     => 4,
                                             },
                                             {
@@ -533,7 +533,7 @@ our $results = [
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 16.0207688808441,
+      "func.elapsed_time"              => 17.5896790027618,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.039,
@@ -571,12 +571,12 @@ our $results = [
       "func.precision"                 => 7,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::InitTarget",
       "func.scenario_module_md5sum"    => "031be9742810dd7b169251894d4ad410",
-      "func.scenario_module_mtime"     => 1498983436,
+      "func.scenario_module_mtime"     => 1499939908,
       "func.scenario_module_sha1sum"   => "04369046d22a6d1e2ce7ae2fc07be5e54ddf2e04",
       "func.scenario_module_sha256sum" => "733fb6fa020e5d8133f3addf99e97085c8878254367f5d714a603650c8820b2f",
-      "func.time_end"                  => 1498984202.19135,
+      "func.time_end"                  => 1499940738.21735,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498984186.17058,
+      "func.time_start"                => 1499940720.62767,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
