@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::NullOutput;
 
-our $VERSION = 0.009; # VERSION
+our $VERSION = "0.010"; # VERSION
 
 our $results = [
   [
@@ -8,107 +8,107 @@ our $results = [
     "OK",
     [
       {
-        errors => 0.00025,
+        errors => 0.00066,
         participant => "Log::Log4perl::Tiny-1mil_trace",
-        rate => 0.842,
+        rate => 0.792,
         samples => 6,
-        time => 1190,
+        time => 1260,
         vs_slowest => 1,
       },
       {
-        errors => 0.00036,
+        errors => 0.0012,
         participant => "Log::Any-null_adapter-1mil_log_trace",
-        rate => 1.43,
+        rate => 1.3,
         samples => 6,
-        time => 700,
+        time => 760,
         vs_slowest => 1.7,
       },
       {
-        errors => 0.00019,
+        errors => 0.0015,
         participant => "Log::Fast-1mil_is_debug",
-        rate => 2.03,
+        rate => 1.9,
         samples => 6,
-        time => 492,
-        vs_slowest => 2.41,
+        time => 520,
+        vs_slowest => 2.4,
       },
       {
-        errors => 0.00054,
-        participant => "Log::Any-null_adapter-1mil_is_trace",
-        rate => 2.4,
-        samples => 6,
-        time => 410,
-        vs_slowest => 2.9,
-      },
-      {
-        errors => 0.00059,
+        errors => 0.0075,
         participant => "Log::Any-no_adapter-1mil_is_trace",
-        rate => 2.5,
+        rate => 2,
         samples => 6,
-        time => 410,
+        time => 500,
+        vs_slowest => 3,
+      },
+      {
+        errors => 0.00099,
+        participant => "Log::Any-null_adapter-1mil_is_trace",
+        rate => 2.3,
+        samples => 8,
+        time => 440,
         vs_slowest => 2.9,
       },
       {
-        errors => 0.00024,
+        errors => 0.00029,
         participant => "Log::Log4perl-easy-1mil_trace",
-        rate => 3.28,
-        samples => 8,
-        time => 305,
-        vs_slowest => 3.89,
+        rate => 3.1,
+        samples => 6,
+        time => 323,
+        vs_slowest => 3.92,
       },
       {
-        errors => 0.00035,
+        errors => 0.00057,
         participant => "Log::Any-no_adapter-1mil_log_trace",
-        rate => 6.6,
+        rate => 6.1,
         samples => 6,
-        time => 150,
-        vs_slowest => 7.8,
+        time => 160,
+        vs_slowest => 7.7,
       },
       {
-        errors => 0.00019,
+        errors => 0.00041,
         participant => "Log::Fast-1mil_DEBUG",
-        rate => 6.8,
-        samples => 8,
+        rate => 6.5,
+        samples => 6,
         time => 150,
-        vs_slowest => 8.1,
+        vs_slowest => 8.2,
       },
       {
-        errors => 0.00038,
-        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
-        rate => 9.7,
-        samples => 7,
-        time => 100,
-        vs_slowest => 11,
-      },
-      {
-        errors => 0.00014,
+        errors => 0.0013,
         participant => "Log::ger+LGP:MutilevelLog-1mil_log_6",
-        rate => 9.7,
+        rate => 8,
         samples => 6,
         time => 100,
+        vs_slowest => 10,
+      },
+      {
+        errors => 0.001,
+        participant => "Log::ger+LGP:MutilevelLog-1mil_log_trace",
+        rate => 8.8,
+        samples => 8,
+        time => 110,
         vs_slowest => 11,
       },
       {
-        errors => 8.9e-05,
-        participant => "Log::ger-1mil_log_is_trace",
-        rate => 9.98,
-        samples => 6,
-        time => 100,
-        vs_slowest => 11.8,
-      },
-      {
-        errors => 0.0004,
+        errors => 0.00028,
         participant => "Log::ger-1mil_log_trace",
         rate => 10,
-        samples => 7,
-        time => 100,
-        vs_slowest => 12,
+        samples => 6,
+        time => 97,
+        vs_slowest => 13,
       },
       {
-        errors => 0.00023,
-        participant => "Log::ger+LGP:OptAway-1mil_log_trace",
-        rate => 22,
+        errors => 0.00028,
+        participant => "Log::ger-1mil_log_is_trace",
+        rate => 11,
         samples => 6,
-        time => 45,
+        time => 92,
+        vs_slowest => 14,
+      },
+      {
+        errors => 0.00032,
+        participant => "Log::ger+LGP:OptAway-1mil_log_trace",
+        rate => 21,
+        samples => 6,
+        time => 49,
         vs_slowest => 26,
       },
     ],
@@ -232,7 +232,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2299.992,
+                                              speed                        => 2031.695,
                                               stepping                     => 4,
                                             },
                                             {
@@ -347,7 +347,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => 2277.789,
+                                              speed                        => "2099.890",
                                               stepping                     => 4,
                                             },
                                             {
@@ -462,7 +462,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2299.828,
+                                              speed                        => "2100.000",
                                               stepping                     => 4,
                                             },
                                             {
@@ -577,11 +577,11 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2261.929,
+                                              speed                        => 2010.968,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 38.4515199661255,
+      "func.elapsed_time"              => 42.2324140071869,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__" => 1.039,
@@ -590,9 +590,9 @@ our $results = [
                                             "Devel::Platform::Info" => 0.16,
                                             "Log::Any" => 1.042,
                                             "Log::Fast" => "v2.0.0",
-                                            "Log::ger" => 0.012,
-                                            "Log::ger::Plugin::MultilevelLog" => 0.012,
-                                            "Log::ger::Plugin::OptAway" => 0.003,
+                                            "Log::ger" => 0.016,
+                                            "Log::ger::Plugin::MultilevelLog" => 0.016,
+                                            "Log::ger::Plugin::OptAway" => 0.004,
                                             "Log::Log4perl" => 1.47,
                                             "Log::Log4perl::Tiny" => "1.4.0",
                                             "perl" => "v5.24.0",
@@ -629,9 +629,9 @@ our $results = [
       "func.scenario_module_mtime"     => 1498961728,
       "func.scenario_module_sha1sum"   => "039e31b9d8b409b777cec032562b21d37edab395",
       "func.scenario_module_sha256sum" => "2c90a1da76fe91703dde63d313d2d6c2813756ff795c84aa312c5475396a63bf",
-      "func.time_end"                  => 1498984249.39156,
+      "func.time_end"                  => 1499940790.05205,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498984210.94004,
+      "func.time_start"                => 1499940747.81964,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
