@@ -1,6 +1,6 @@
 package Bencher::ScenarioR::LogGer::OutputStartup;
 
-our $VERSION = 0.009; # VERSION
+our $VERSION = "0.010"; # VERSION
 
 our $results = [
   [
@@ -8,204 +8,204 @@ our $results = [
     "OK",
     [
       {
-        errors => 4.3e-05,
+        errors => 0.00014,
         participant => "init-with-FileWriteRotate",
-        rate => 20.4,
+        rate => 19,
         samples => 20,
-        time => 49,
+        time => 54,
         vs_slowest => 1,
       },
       {
-        errors => 4.6e-05,
+        errors => 9.1e-05,
         participant => "init-with-LogDispatchOutput",
-        rate => 35,
-        samples => 20,
-        time => 29,
+        rate => 31,
+        samples => 22,
+        time => 32,
         vs_slowest => 1.7,
       },
       {
-        errors => 5e-05,
+        errors => 7.5e-05,
         participant => "init-with-LogAny",
-        rate => 53,
+        rate => 46,
         samples => 21,
-        time => 19,
+        time => 22,
+        vs_slowest => 2.5,
+      },
+      {
+        errors => 9.8e-05,
+        participant => "init-with-Composite",
+        rate => 48,
+        samples => 20,
+        time => 21,
         vs_slowest => 2.6,
       },
       {
-        errors => 0.00011,
-        participant => "init-with-Composite",
-        rate => 56,
+        errors => 8.4e-05,
+        participant => "init-with-DirWriteRotate",
+        rate => 51,
         samples => 20,
-        time => 18,
-        vs_slowest => 2.7,
+        time => 19,
+        vs_slowest => 2.8,
       },
       {
-        errors => 7.8e-05,
-        participant => "init-with-DirWriteRotate",
-        rate => 60,
-        samples => 21,
-        time => 17,
-        vs_slowest => 2.9,
+        errors => 4.9e-05,
+        participant => "init-with-String",
+        rate => 66,
+        samples => 20,
+        time => 15,
+        vs_slowest => 3.5,
+      },
+      {
+        errors => 5.3e-05,
+        participant => "init-with-Null",
+        rate => 66,
+        samples => 20,
+        time => 15,
+        vs_slowest => 3.6,
       },
       {
         errors => 5.1e-05,
         participant => "init-with-Screen",
-        rate => 78,
-        samples => 20,
-        time => 13,
-        vs_slowest => 3.8,
-      },
-      {
-        errors => 4.3e-05,
-        participant => "init-with-File",
-        rate => 78,
-        samples => 20,
-        time => 13,
-        vs_slowest => 3.8,
-      },
-      {
-        errors => 5.7e-05,
-        participant => "init-with-Null",
-        rate => 79,
+        rate => 67,
         samples => 21,
-        time => 13,
-        vs_slowest => 3.9,
-      },
-      {
-        errors => 3.6e-05,
-        participant => "init-with-Array",
-        rate => 79,
-        samples => 20,
-        time => 13,
-        vs_slowest => 3.9,
+        time => 15,
+        vs_slowest => 3.6,
       },
       {
         errors => 4.2e-05,
-        participant => "init-with-String",
-        rate => 79,
+        participant => "init-with-File",
+        rate => 67,
         samples => 20,
-        time => 13,
-        vs_slowest => 3.9,
+        time => 15,
+        vs_slowest => 3.6,
       },
       {
-        errors => 4.1e-05,
-        participant => "init-with-Callback",
-        rate => 80,
-        samples => 20,
-        time => 12,
-        vs_slowest => 3.9,
-      },
-      {
-        errors => 3.7e-05,
-        participant => "init-with-ArrayWithLimits",
-        rate => 80,
-        samples => 20,
-        time => 12,
-        vs_slowest => 3.9,
-      },
-      {
-        errors => 1.5e-05,
-        participant => "load-Screen",
-        rate => 90,
-        samples => 20,
-        time => 11,
-        vs_slowest => 4.4,
-      },
-      {
-        errors => 2.7e-05,
-        participant => "load-LogDispatchOutput",
-        rate => 91,
-        samples => 20,
-        time => 11,
-        vs_slowest => 4.5,
-      },
-      {
-        errors => 2.8e-05,
-        participant => "load-Composite",
-        rate => 120,
-        samples => 20,
-        time => 8.5,
-        vs_slowest => 5.7,
-      },
-      {
-        errors => 3.6e-05,
-        participant => "load-LogAny",
-        rate => 130,
-        samples => 20,
-        time => 7.8,
-        vs_slowest => 6.3,
+        errors => 3.3e-05,
+        participant => "init-with-Array",
+        rate => 67,
+        samples => 21,
+        time => 15,
+        vs_slowest => 3.6,
       },
       {
         errors => 2.2e-05,
-        participant => "load-File",
-        rate => 130,
+        participant => "init-with-ArrayWithLimits",
+        rate => 67,
         samples => 20,
-        time => 7.8,
-        vs_slowest => 6.3,
+        time => 15,
+        vs_slowest => 3.6,
       },
       {
-        errors => 1.6e-05,
-        participant => "load-FileWriteRotate",
-        rate => 130,
+        errors => 7.3e-05,
+        participant => "init-with-Callback",
+        rate => 68,
         samples => 20,
-        time => 7.7,
-        vs_slowest => 6.3,
-      },
-      {
-        errors => 1.6e-05,
-        participant => "load-String",
-        rate => 130,
-        samples => 21,
-        time => 7.7,
-        vs_slowest => 6.4,
+        time => 15,
+        vs_slowest => 3.7,
       },
       {
         errors => 3.7e-05,
-        participant => "load-Array",
-        rate => 130,
+        participant => "load-Screen",
+        rate => 75,
         samples => 20,
-        time => 7.7,
-        vs_slowest => 6.4,
+        time => 13,
+        vs_slowest => 4,
       },
       {
-        errors => 9.9e-06,
-        participant => "load-ArrayWithLimits",
-        rate => 130,
-        samples => 20,
-        time => 7.6,
-        vs_slowest => 6.4,
-      },
-      {
-        errors => 2.5e-05,
-        participant => "load-Callback",
-        rate => 130,
+        errors => 5.7e-05,
+        participant => "load-LogDispatchOutput",
+        rate => 76,
         samples => 21,
-        time => 7.6,
-        vs_slowest => 6.4,
+        time => 13,
+        vs_slowest => 4.1,
       },
       {
-        errors => 2.3e-05,
+        errors => 3e-05,
+        participant => "load-Composite",
+        rate => 95,
+        samples => 20,
+        time => 11,
+        vs_slowest => 5.1,
+      },
+      {
+        errors => 3.9e-05,
+        participant => "load-Callback",
+        rate => 100,
+        samples => 20,
+        time => 9.8,
+        vs_slowest => 5.5,
+      },
+      {
+        errors => 2.4e-05,
         participant => "load-DirWriteRotate",
-        rate => 130,
+        rate => 100,
         samples => 20,
-        time => 7.5,
-        vs_slowest => 6.5,
+        time => 9.6,
+        vs_slowest => 5.6,
       },
       {
-        errors => 2.1e-05,
+        errors => 2.6e-05,
+        participant => "load-File",
+        rate => 100,
+        samples => 20,
+        time => 9.6,
+        vs_slowest => 5.6,
+      },
+      {
+        errors => 3.4e-05,
+        participant => "load-ArrayWithLimits",
+        rate => 100,
+        samples => 20,
+        time => 9.6,
+        vs_slowest => 5.6,
+      },
+      {
+        errors => 1.4e-05,
+        participant => "load-LogAny",
+        rate => 110,
+        samples => 21,
+        time => 9.5,
+        vs_slowest => 5.7,
+      },
+      {
+        errors => 1.5e-05,
+        participant => "load-FileWriteRotate",
+        rate => 110,
+        samples => 20,
+        time => 9.5,
+        vs_slowest => 5.7,
+      },
+      {
+        errors => 5.2e-05,
+        participant => "load-String",
+        rate => 110,
+        samples => 20,
+        time => 9.5,
+        vs_slowest => 5.7,
+      },
+      {
+        errors => 1.8e-05,
+        participant => "load-Array",
+        rate => 110,
+        samples => 20,
+        time => 9.5,
+        vs_slowest => 5.7,
+      },
+      {
+        errors => 2.4e-05,
         participant => "load-Null",
-        rate => 190,
+        rate => 140,
         samples => 20,
-        time => 5.4,
-        vs_slowest => 9.1,
+        time => 7.1,
+        vs_slowest => 7.6,
       },
       {
-        errors => 7.4e-06,
+        errors => 1.7e-05,
         participant => "baseline",
-        rate => 200,
+        rate => 150,
         samples => 20,
-        time => 5,
-        vs_slowest => 9.7,
+        time => 6.7,
+        vs_slowest => 8,
       },
     ],
     {
@@ -328,7 +328,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 0,
-                                              speed                        => 2248.585,
+                                              speed                        => 2199.968,
                                               stepping                     => 4,
                                             },
                                             {
@@ -443,7 +443,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 1,
-                                              speed                        => "2264.500",
+                                              speed                        => 2199.968,
                                               stepping                     => 4,
                                             },
                                             {
@@ -558,7 +558,7 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 2,
-                                              speed                        => 2239.726,
+                                              speed                        => 2199.968,
                                               stepping                     => 4,
                                             },
                                             {
@@ -673,29 +673,29 @@ our $results = [
                                               number_of_cores              => 2,
                                               number_of_logical_processors => 4,
                                               processor_id                 => 3,
-                                              speed                        => 2299.992,
+                                              speed                        => 2200.023,
                                               stepping                     => 4,
                                             },
                                           ],
-      "func.elapsed_time"              => 7.82487297058105,
+      "func.elapsed_time"              => 9.7668092250824,
       "func.module_startup"            => undef,
       "func.module_versions"           => {
                                             "__PACKAGE__"                              => 1.039,
                                             "Bencher::Scenario::LogGer::OutputStartup" => undef,
                                             "Benchmark::Dumb"                          => "0.10",
                                             "Devel::Platform::Info"                    => 0.16,
-                                            "Log::ger::Output::Array"                  => 0.012,
+                                            "Log::ger::Output::Array"                  => 0.016,
                                             "Log::ger::Output::ArrayWithLimits"        => 0.001,
-                                            "Log::ger::Output::Callback"               => 0.001,
+                                            "Log::ger::Output::Callback"               => 0.002,
                                             "Log::ger::Output::Composite"              => 0.007,
                                             "Log::ger::Output::DirWriteRotate"         => 0.002,
                                             "Log::ger::Output::File"                   => 0.002,
                                             "Log::ger::Output::FileWriteRotate"        => 0.001,
                                             "Log::ger::Output::LogAny"                 => 0.006,
                                             "Log::ger::Output::LogDispatchOutput"      => 0.001,
-                                            "Log::ger::Output::Null"                   => 0.012,
+                                            "Log::ger::Output::Null"                   => 0.016,
                                             "Log::ger::Output::Screen"                 => 0.005,
-                                            "Log::ger::Output::String"                 => 0.012,
+                                            "Log::ger::Output::String"                 => 0.016,
                                             "perl"                                     => "v5.24.0",
                                             "Sys::Info"                                => 0.78,
                                           },
@@ -726,13 +726,13 @@ our $results = [
                                           },
       "func.precision"                 => 0,
       "func.scenario_module"           => "Bencher::Scenario::LogGer::OutputStartup",
-      "func.scenario_module_md5sum"    => "5ff6bf9535492bc7dd14fb5d75614094",
-      "func.scenario_module_mtime"     => 1498984087,
-      "func.scenario_module_sha1sum"   => "c6ac15237615c226c55efb47506be2a79e33a120",
-      "func.scenario_module_sha256sum" => "12c749fa9b4d6e718fdc9b29cc8a037b9a982482340ad2aae1fcd5f842bd3938",
-      "func.time_end"                  => 1498984258.61965,
+      "func.scenario_module_md5sum"    => "13f633df643d5af9a298e3d2229486ae",
+      "func.scenario_module_mtime"     => 1499940597,
+      "func.scenario_module_sha1sum"   => "32a1617bc223d185e149e11816d426e7e98f8c54",
+      "func.scenario_module_sha256sum" => "9dfe26981431e7b667bbe46e603ff819b163f93c1fa93c3f2ae2b360431527a7",
+      "func.time_end"                  => 1499940801.54025,
       "func.time_factor"               => 1000,
-      "func.time_start"                => 1498984250.79478,
+      "func.time_start"                => 1499940791.77344,
       "table.field_aligns"             => ["left", "left", "number", "number", "number", "number", "number"],
       "table.field_units"              => [undef, undef, "/s", "ms"],
       "table.fields"                   => [
